@@ -92,7 +92,7 @@ html_image_get_actual_width (HTMLImage *image, HTMLPainter *painter)
 		width = gdk_pixbuf_animation_get_width (anim) * pixel_size;
 
 		if (image->specified_height > 0 || image->percent_height) {
-			double scale;
+			gdouble scale;
 
 			scale =  ((double) html_image_get_actual_height (image, painter))
 				/ (gdk_pixbuf_animation_get_height (anim) * pixel_size);
@@ -125,7 +125,7 @@ html_image_get_actual_height (HTMLImage *image, HTMLPainter *painter)
 		height = gdk_pixbuf_animation_get_height (anim) * pixel_size;
 
 		if (image->specified_width > 0 || image->percent_width) {
-			double scale;
+			gdouble scale;
 
 			scale = ((double) html_image_get_actual_width (image, painter))
 				/ (gdk_pixbuf_animation_get_width (anim) * pixel_size);
@@ -378,8 +378,8 @@ static void
 draw_focus  (HTMLImage *image, HTMLPainter *painter, GdkRectangle *box)
 {
 	HTMLGdkPainter *p;
-	GdkGCValues values;
-	gint8 dash_list[] = { 1, 1 };
+	const double dashes[] = { 1, 1 };
+	gint ndash = G_N_ELEMENTS (dashes);
 	HTMLEngine *e;
 
 	if (painter->widget && GTK_IS_HTML (painter->widget))
@@ -393,14 +393,15 @@ draw_focus  (HTMLImage *image, HTMLPainter *painter, GdkRectangle *box)
 	p = HTML_GDK_PAINTER (painter);
 	/* printf ("draw_image_focus\n"); */
 
-	gdk_gc_set_foreground (p->gc, &html_colorset_get_color_allocated (e->settings->color_set,
-									  painter, HTMLTextColor)->color);
-	gdk_gc_get_values (p->gc, &values);
-
-	gdk_gc_set_line_attributes (p->gc, 1, GDK_LINE_ON_OFF_DASH, values.cap_style, values.join_style);
-	gdk_gc_set_dashes (p->gc, 2, dash_list, 2);
-	gdk_draw_rectangle (p->pixmap, p->gc, 0, box->x - p->x1, box->y - p->y1, box->width - 1, box->height - 1);
-	gdk_gc_set_line_attributes (p->gc, 1, values.line_style, values.cap_style, values.join_style);
+	cairo_save (p->cr);
+	gdk_cairo_set_source_color (p->cr,
+				    &html_colorset_get_color_allocated (e->settings->color_set,
+									painter, HTMLTextColor)->color);
+	cairo_set_line_cap (p->cr, CAIRO_LINE_CAP_ROUND);
+	cairo_set_dash (p->cr, dashes, ndash, 2);
+	cairo_rectangle (p->cr, box->x - p->x1, box->y - p->y1, box->width - 1, box->height - 1);
+	cairo_stroke (p->cr);
+	cairo_restore (p->cr);
 }
 
 static void
@@ -873,7 +874,7 @@ html_image_new (HTMLImageFactory *imf,
 {
 	HTMLImage *image;
 
-	image = g_new(HTMLImage, 1);
+	image = g_new (HTMLImage, 1);
 
 	html_image_init (image, &html_image_class,
 			 imf,
@@ -1057,7 +1058,8 @@ html_image_factory_types (GtkHTMLStream *stream,
 }
 
 static void
-update_or_redraw (HTMLImagePointer *ip){
+update_or_redraw (HTMLImagePointer *ip)
+{
 	GSList *list;
 	gboolean update = FALSE;
 
@@ -1146,7 +1148,7 @@ html_image_factory_write_pixbuf (GtkHTMLStream *stream,
 {
 	HTMLImagePointer *p = user_data;
 
-	/* FIXME ! Check return value */
+	/* FIXME !Check return value */
 	gdk_pixbuf_loader_write (p->loader, (const guchar *) buffer, size, NULL);
 }
 
@@ -1160,13 +1162,13 @@ html_image_pointer_queue_animation (HTMLImagePointer *ip)
 		delay = gdk_pixbuf_animation_iter_get_delay_time (ip->iter);
 
 		ip->animation_timeout = g_timeout_add (delay,
-						       (GtkFunction) html_image_pointer_update,
+						       (GSourceFunc) html_image_pointer_update,
 						       (gpointer) ip);
 	}
 
 }
 
-static gint
+static gboolean
 html_image_pointer_update (HTMLImagePointer *ip)
 {
 	HTMLEngine *engine;
@@ -1262,7 +1264,7 @@ cleanup_images (gpointer key, gpointer value, gpointer free_everything)
 	HTMLImagePointer *ip = value;
 
 	/* free_everything means: NULL only clean, non-NULL free */
-	if (free_everything){
+	if (free_everything) {
 		if (ip->interests != NULL) {
 			g_slist_free (ip->interests);
 			ip->interests = NULL;
@@ -1270,7 +1272,7 @@ cleanup_images (gpointer key, gpointer value, gpointer free_everything)
 	}
 
 	/* clean only if this image is not used anymore */
-	if (!ip->interests){
+	if (!ip->interests) {
 		html_image_pointer_unref (ip);
 		ip->factory = NULL;
 		return TRUE;
@@ -1317,7 +1319,7 @@ html_image_pointer_new (const gchar *filename, HTMLImageFactory *factory)
 	retval->factory = factory;
 	retval->stall = FALSE;
 	retval->stall_timeout = g_timeout_add (STALL_INTERVAL,
-					       (GtkFunction)html_image_pointer_timeout,
+					       (GSourceFunc)html_image_pointer_timeout,
 					       retval);
 	retval->animation_timeout = 0;
 	return retval;
@@ -1576,7 +1578,6 @@ deactivate_anim (gpointer key, gpointer value, gpointer user_data)
 	GSList *cur = ip->interests;
 	HTMLImage *image;
 
-
 	while (cur) {
 		if (cur->data) {
 			image = (HTMLImage *) cur->data;
